@@ -7,6 +7,8 @@
  * Contract with IBM Corp.
  ****************************************************************************** */
 /* Copyright (c) 2020 Red Hat, Inc. */
+/* Copyright Contributors to the Open Cluster Management project */
+
 
 export const staticResourceData = {
   'defaultSortField': 'metadata.name',
@@ -40,302 +42,6 @@ export const staticResourceData = {
       }
     ]
   },
-  'placementBindingKeys': {
-    'title': 'application.placement.bindings',
-    'defaultSortField': 'name',
-    'resourceKey': 'placementBindings',
-    'tableKeys': [
-      {
-        'key': 'name',
-        'resourceKey': 'metadata.name',
-        'msgKey': 'table.header.name'
-      },
-      {
-        'key': 'namespace',
-        'resourceKey': 'metadata.namespace',
-        'msgKey': 'table.header.namespace'
-      },
-      {
-        'key': 'placementpolicy',
-        'resourceKey': 'placementRef.name',
-        'msgKey': 'table.header.placementpolicy'
-      },
-      {
-        'key': 'subjects',
-        'resourceKey': 'subjects',
-        'msgKey': 'table.header.subjects'
-      },
-      {
-        'key': 'timestamp',
-        'resourceKey': 'metadata.creationTimestamp',
-        'msgKey': 'table.header.created'
-      }
-    ],
-    'detailKeys': {
-      'title': 'policy.pb.details.title',
-      'headerRows': [
-        'type',
-        'detail'
-      ],
-      'rows': [
-        {
-          'cells': [
-            {
-              'resourceKey': 'policy.pb.details.name',
-              'type': 'i18n'
-            },
-            {
-              'resourceKey': 'metadata.name'
-            }
-          ]
-        },
-        {
-          'cells': [
-            {
-              'resourceKey': 'policy.pb.details.namespace',
-              'type': 'i18n'
-            },
-            {
-              'resourceKey': 'metadata.namespace'
-            }
-          ]
-        },
-        {
-          'cells': [
-            {
-              'resourceKey': 'policy.pb.details.pp',
-              'type': 'i18n'
-            },
-            {
-              'resourceKey': 'placementRef.name'
-            }
-          ]
-        },
-        {
-          'cells': [
-            {
-              'resourceKey': 'policy.pb.details.subjects',
-              'type': 'i18n'
-            },
-            {
-              'resourceKey': 'subjects[0]'
-            }
-          ]
-        },
-        {
-          'cells': [
-            {
-              'resourceKey': 'policy.pb.details.timestamp',
-              'type': 'i18n'
-            },
-            {
-              'resourceKey': 'metadata.creationTimestamp'
-            }
-          ]
-        }
-      ]
-    },
-    'tableActions': [
-      'table.actions.edit'
-    ]
-  },
-  'placementPolicyKeys': {
-    'title': 'application.placement.policies',
-    'defaultSortField': 'name',
-    'resourceKey': 'placementPolicies',
-    'tableKeys': [
-      {
-        'key': 'name',
-        'resourceKey': 'metadata.name',
-        'msgKey': 'table.header.name'
-      },
-      {
-        'key': 'namespace',
-        'resourceKey': 'metadata.namespace',
-        'msgKey': 'table.header.namespace'
-      },
-      {
-        'key': 'clusterSelector',
-        'resourceKey': 'clusterLabels',
-        'msgKey': 'table.header.cluster.selector'
-      },
-      {
-        'key': 'decisions',
-        'resourceKey': 'status',
-        'msgKey': 'table.header.decisions'
-      },
-      {
-        'key': 'timestamp',
-        'resourceKey': 'metadata.creationTimestamp',
-        'msgKey': 'table.header.created'
-      }
-    ],
-    'detailKeys': {
-      'title': 'policy.pp.details.title',
-      'headerRows': [
-        'type',
-        'detail'
-      ],
-      'rows': [
-        {
-          'cells': [
-            {
-              'resourceKey': 'policy.pp.details.name',
-              'type': 'i18n'
-            },
-            {
-              'resourceKey': 'metadata.name'
-            }
-          ]
-        },
-        {
-          'cells': [
-            {
-              'resourceKey': 'policy.pp.details.namespace',
-              'type': 'i18n'
-            },
-            {
-              'resourceKey': 'metadata.namespace'
-            }
-          ]
-        },
-        {
-          'cells': [
-            {
-              'resourceKey': 'policy.pp.details.clusterSelector',
-              'type': 'i18n'
-            },
-            {
-              'resourceKey': 'clusterLabels'
-            }
-          ]
-        },
-        {
-          'cells': [
-            {
-              'resourceKey': 'policy.pp.details.decisions',
-              'type': 'i18n'
-            },
-            {
-              'resourceKey': 'status'
-            }
-          ]
-        },
-        {
-          'cells': [
-            {
-              'resourceKey': 'policy.pp.details.timestamp',
-              'type': 'i18n'
-            },
-            {
-              'resourceKey': 'metadata.creationTimestamp'
-            }
-          ]
-        }
-      ]
-    },
-    'tableActions': [
-      'table.actions.edit'
-    ]
-  },
-  'roleTemplates': {
-    'resourceKey': 'role-templates',
-    'title': 'table.header.role.template',
-    'defaultSortField': 'metadata.name',
-    'normalizedKey': 'metadata.name',
-    'tableKeys': [
-      {
-        'msgKey': 'table.header.role.template.name',
-        'resourceKey': 'metadata.name',
-        'key': 'name'
-      },
-      {
-        'msgKey': 'table.header.role.template.complianceType',
-        'resourceKey': 'complianceType',
-        'key': 'complianceType'
-      },
-      {
-        'msgKey': 'table.header.role.template.apiVersion',
-        'resourceKey': 'apiVersion',
-        'key': 'apiVersion'
-      },
-      {
-        'msgKey': 'table.header.role.template.lastTransition',
-        'resourceKey': 'status.conditions[0].lastTransitionTime',
-        'key': 'lastTransition'
-      },
-      {
-        'msgKey': 'table.header.role.template.status',
-        'resourceKey': 'status.Compliant',
-        'key': 'status'
-      }
-    ],
-    'rows': [
-      {
-        'cells': [
-          {
-            'resourceKey': 'metadata.name'
-          },
-          {
-            'resourceKey': 'complianceType'
-          },
-          {
-            'resourceKey': 'apiVersion'
-          },
-          {
-            'resourceKey': 'status.conditions[0].lastTransitionTime'
-          },
-          {
-            'resourceKey': 'status.Compliant'
-          }
-        ]
-      }
-    ],
-    'subHeaders': [
-      'table.header.role.template.complianceType',
-      'table.header.apiGroups',
-      'table.header.resources',
-      'table.header.ruleVerbs'
-    ]
-  },
-  'objectTemplates': {
-    'resourceKey': 'object-templates',
-    'title': 'table.header.object.template',
-    'defaultSortField': 'objectDefinition.metadata.name',
-    'normalizedKey': 'objectDefinition.metadata.name',
-    'tableKeys': [
-      {
-        'msgKey': 'table.header.object.template.name',
-        'resourceKey': 'objectDefinition.metadata.name',
-        'key': 'name'
-      },
-      {
-        'msgKey': 'table.header.object.template.complianceType',
-        'resourceKey': 'complianceType',
-        'key': 'complianceType'
-      },
-      {
-        'msgKey': 'table.header.object.template.apiVersion',
-        'resourceKey': 'objectDefinition.apiVersion',
-        'key': 'apiVersion'
-      },
-      {
-        'msgKey': 'table.header.object.template.kind',
-        'resourceKey': 'objectDefinition.kind',
-        'key': 'kind'
-      },
-      {
-        'msgKey': 'table.header.object.template.lastTransition',
-        'resourceKey': 'status.conditions[0].lastTransitionTime',
-        'key': 'lastTransition'
-      },
-      {
-        'msgKey': 'table.header.object.template.status',
-        'resourceKey': 'status.Compliant',
-        'key': 'status'
-      }
-    ]
-  },
   'policyTemplates': {
     'resourceKey': 'policy-templates',
     'title': 'table.header.policy.template',
@@ -458,7 +164,7 @@ export const staticResourceData = {
       {
         'cells': [
           {
-            'resourceKey': 'description.title.enforcement',
+            'resourceKey': 'description.title.remediation',
             'type': 'i18n'
           },
           {
@@ -676,11 +382,11 @@ export const staticResourceData = {
       {
         'cells': [
           {
-            'resourceKey': 'description.title.enforcement',
+            'resourceKey': 'description.title.remediation',
             'type': 'i18n'
           },
           {
-            'resourceKey': 'enforcement'
+            'resourceKey': 'remediation'
           }
         ]
       },
@@ -762,11 +468,11 @@ export const staticResourceData = {
       {
         'cells': [
           {
-            'resourceKey': 'description.title.enforcement',
+            'resourceKey': 'description.title.remediation',
             'type': 'i18n'
           },
           {
-            'resourceKey': 'enforcement'
+            'resourceKey': 'remediation'
           }
         ]
       },
@@ -794,110 +500,6 @@ export const staticResourceData = {
       }
     ]
   },
-  'policyRoleTemplates': {
-    'title': 'table.header.roleTemplates',
-    'defaultSortField': 'name',
-    'normalizedKey': 'name',
-    'resourceKey': 'roleTemplates',
-    'tableKeys': [
-      {
-        'msgKey': 'table.header.name',
-        'resourceKey': 'name',
-        'key': 'name'
-      },
-      {
-        'msgKey': 'table.header.complianceType',
-        'resourceKey': 'complianceType',
-        'key': 'complianceType'
-      },
-      {
-        'msgKey': 'description.title.api.version',
-        'resourceKey': 'apiVersion',
-        'key': 'apiVersion'
-      },
-      {
-        'msgKey': 'description.title.last.transition',
-        'resourceKey': 'lastTransition',
-        'key': 'lastTransition'
-      },
-      {
-        'msgKey': 'table.header.compliant',
-        'resourceKey': 'compliant',
-        'key': 'compliant'
-      }
-    ]
-  },
-  'policyRoleBindingTemplates': {
-    'title': 'table.header.roleBindingTemplates',
-    'defaultSortField': 'name',
-    'normalizedKey': 'name',
-    'resourceKey': 'roleBindingTemplates',
-    'tableKeys': [
-      {
-        'msgKey': 'table.header.name',
-        'resourceKey': 'name',
-        'key': 'name'
-      },
-      {
-        'msgKey': 'table.header.complianceType',
-        'resourceKey': 'complianceType',
-        'key': 'complianceType'
-      },
-      {
-        'msgKey': 'description.title.api.version',
-        'resourceKey': 'apiVersion',
-        'key': 'apiVersion'
-      },
-      {
-        'msgKey': 'description.title.last.transition',
-        'resourceKey': 'lastTransition',
-        'key': 'lastTransition'
-      },
-      {
-        'msgKey': 'table.header.compliant',
-        'resourceKey': 'compliant',
-        'key': 'compliant'
-      }
-    ]
-  },
-  'policyObjectTemplates': {
-    'title': 'table.header.objectTemplates',
-    'defaultSortField': 'name',
-    'normalizedKey': 'name',
-    'resourceKey': 'objectTemplates',
-    'tableKeys': [
-      {
-        'msgKey': 'table.header.name',
-        'resourceKey': 'name',
-        'key': 'name'
-      },
-      {
-        'msgKey': 'table.header.complianceType',
-        'resourceKey': 'complianceType',
-        'key': 'complianceType'
-      },
-      {
-        'msgKey': 'description.title.api.version',
-        'resourceKey': 'apiVersion',
-        'key': 'apiVersion'
-      },
-      {
-        'msgKey': 'table.header.kind',
-        'resourceKey': 'kind',
-        'key': 'kind'
-      },
-      {
-        'msgKey': 'description.title.last.transition',
-        'resourceKey': 'lastTransition',
-        'key': 'lastTransition'
-      },
-      {
-        'msgKey': 'table.header.compliant',
-        'resourceKey': 'compliant',
-        'key': 'compliant'
-      }
-    ]
-  },
   'policyPolicyTemplates': {
     'title': 'table.header.policyTemplates',
     'defaultSortField': 'name',
@@ -1199,8 +801,6 @@ export const items = [
         'complianceName': '1570049336008-policy-test',
         'complianceNamespace': 'mcm',
         'complianceSelfLink': '/apis/policy.open-cluster-management.io/v1/namespaces/mcm/policies/1570049336008-policy-test',
-        'roleTemplates': [],
-        'roleBindingTemplates': [],
         'objectTemplates': [
           {
             'apiVersion': 'v1',
@@ -1420,7 +1020,7 @@ export const items = [
             'complianceName': '1570049336008-policy-test',
             'complianceNamespace': 'mcm',
             'valid': 'unknown',
-            'enforcement': 'unknown',
+            'remediation': 'unknown',
             'status': 'Compliant',
             'raw': null,
             'metadata': {
@@ -1437,9 +1037,7 @@ export const items = [
               'uid': '1c260624-e556-11e9-8895-005056a061f1',
               '__typename': 'Metadata'
             },
-            'roleTemplates': [],
-            'roleBindingTemplates': [],
-            'objectTemplates': [],
+            'policyTemplates': [],
             'rules': [],
             'violations': [],
             '__typename': 'CompliancePolicy'
@@ -1451,7 +1049,7 @@ export const items = [
             'complianceName': '1570049336008-policy-test',
             'complianceNamespace': 'mcm',
             'valid': 'unknown',
-            'enforcement': 'unknown',
+            'remediation': 'unknown',
             'status': 'Compliant',
             'raw': null,
             'metadata': {
@@ -1468,7 +1066,7 @@ export const items = [
               'uid': '1c260624-e556-11e9-8895-005056a061f1',
               '__typename': 'Metadata'
             },
-            'roleTemplates': [],
+            'policyTemplates': [],
             'roleBindingTemplates': [],
             'objectTemplates': [],
             'rules': [],
